@@ -26,15 +26,31 @@ COLUMNS = {
     "created_by": "string",
     "thread_id": "string",
     "total_estimated_cost": "number",
+    "type": "string",
+    "model": "string",
+    "provider": "string",
 }
 
 SUPPORTED_OPERATORS = {
-    "id": ["=", "contains", "not_contains"],
-    "name": ["=", "contains", "not_contains"],
+    "id": ["=", "contains", "not_contains", "starts_with", "ends_with", "!=", ">", "<"],
+    "name": [
+        "=",
+        "contains",
+        "not_contains",
+        "starts_with",
+        "ends_with",
+        "!=",
+        ">",
+        "<",
+    ],
     "status": ["=", "contains", "not_contains"],
     "start_time": ["=", ">", "<", ">=", "<="],
     "end_time": ["=", ">", "<", ">=", "<="],
-    "input": ["=", "contains", "not_contains"],
+    "input": [
+        "=",
+        "contains",
+        "not_contains",
+    ],
     "output": ["=", "contains", "not_contains"],
     "metadata": ["=", "contains", ">", "<"],
     "feedback_scores": ["=", ">", "<", ">=", "<="],
@@ -44,9 +60,57 @@ SUPPORTED_OPERATORS = {
     "usage.completion_tokens": ["=", "!=", ">", "<", ">=", "<="],
     "duration": ["=", "!=", ">", "<", ">=", "<="],
     "number_of_messages": ["=", "!=", ">", "<", ">=", "<="],
-    "created_by": ["=", "contains", "not_contains"],
-    "thread_id": ["=", "contains", "not_contains"],
+    "created_by": [
+        "=",
+        "contains",
+        "not_contains",
+        "starts_with",
+        "ends_with",
+        "!=",
+        ">",
+        "<",
+    ],
+    "thread_id": [
+        "=",
+        "contains",
+        "not_contains",
+        "starts_with",
+        "ends_with",
+        "!=",
+        ">",
+        "<",
+    ],
     "total_estimated_cost": ["=", "!=", ">", "<", ">=", "<="],
+    "type": [
+        "=",
+        "contains",
+        "not_contains",
+        "starts_with",
+        "ends_with",
+        "!=",
+        ">",
+        "<",
+    ],
+    "model": [
+        "=",
+        "contains",
+        "not_contains",
+        "starts_with",
+        "ends_with",
+        "!=",
+        ">",
+        "<",
+    ],
+    "provider": [
+        "=",
+        "contains",
+        "not_contains",
+        "starts_with",
+        "ends_with",
+        "!=",
+        ">",
+        "<",
+    ],
 }
 
 
@@ -226,7 +290,7 @@ class OpikQueryLanguage:
                 self._cursor += 1
 
             operator = self.query_string[start : self._cursor]
-            if operator not in ["contains", "not_contains"]:
+            if operator not in SUPPORTED_OPERATORS[parsed_field]:
                 raise ValueError(
                     f"Operator {operator} is not supported for field {parsed_field}, only the operators {SUPPORTED_OPERATORS[parsed_field]} are supported."
                 )
