@@ -13,7 +13,7 @@ from typing import (
     Union,
 )
 
-from .. import config, context_storage, logging_messages
+from .. import context_storage, logging_messages
 from ..api_objects import opik_client, span, trace
 from ..types import DistributedTraceHeadersDict, ErrorInfoDict, SpanType
 from . import (
@@ -22,6 +22,7 @@ from . import (
     generator_wrappers,
     inspect_helpers,
     span_creation_handler,
+    tracing_runtime_config,
 )
 
 LOGGER = logging.getLogger(__name__)
@@ -48,11 +49,6 @@ class BaseTrackDecorator(abc.ABC):
         self.provider: Optional[str] = None
         """ Name of the LLM provider. Used in subclasses in integrations track decorators. """
 
-    @functools.cached_property
-    def disabled(self) -> bool:
-        config_ = config.OpikConfig()
-        return config_.track_disable
-
     def track(
         self,
         name: Optional[Union[Callable, str]] = None,
@@ -94,6 +90,10 @@ class BaseTrackDecorator(abc.ABC):
             This decorator can be used to track both synchronous and asynchronous functions,
             and also synchronous and asynchronous generators.
             It automatically detects the function type and applies the appropriate tracking logic.
+
+            Tracing is checked only once at the start of the call; a call that
+            began while tracing was enabled will still be logged even if
+            tracing is disabled before it returns.
         """
         track_options = arguments_helpers.TrackOptions(
             name=None,
@@ -177,6 +177,8 @@ class BaseTrackDecorator(abc.ABC):
     ) -> Callable:
         @functools.wraps(func)
         def wrapper(*args, **kwargs) -> Any:  # type: ignore
+            if not tracing_runtime_config.is_tracing_active():
+                return func(*args, **kwargs)
             try:
                 opik_distributed_trace_headers: Optional[
                     DistributedTraceHeadersDict
@@ -225,6 +227,8 @@ class BaseTrackDecorator(abc.ABC):
     ) -> Callable:
         @functools.wraps(func)
         def wrapper(*args, **kwargs) -> Any:  # type: ignore
+            if not tracing_runtime_config.is_tracing_active():
+                return func(*args, **kwargs)
             try:
                 opik_distributed_trace_headers: Optional[
                     DistributedTraceHeadersDict
@@ -273,6 +277,8 @@ class BaseTrackDecorator(abc.ABC):
     ) -> Callable:
         @functools.wraps(func)
         def wrapper(*args, **kwargs) -> Any:  # type: ignore
+            if not tracing_runtime_config.is_tracing_active():
+                return func(*args, **kwargs)
             self._before_call(
                 func=func,
                 track_options=track_options,
@@ -326,6 +332,8 @@ class BaseTrackDecorator(abc.ABC):
     ) -> Callable:
         @functools.wraps(func)
         async def wrapper(*args, **kwargs) -> Any:  # type: ignore
+            if not tracing_runtime_config.is_tracing_active():
+                return await func(*args, **kwargs)
             self._before_call(
                 func=func,
                 track_options=track_options,
@@ -438,14 +446,20 @@ class BaseTrackDecorator(abc.ABC):
         )
         client = opik_client.get_client_cached()
 
-        if client.config.log_start_trace_span:
+        if (
+            client.config.log_start_trace_span
+            and tracing_runtime_config.is_tracing_active()
+        ):
             client.span(**created_span_data.as_start_parameters)
 
         if created_trace_data is not None:
             context_storage.set_trace_data(created_trace_data)
             TRACES_CREATED_BY_DECORATOR.add(created_trace_data.id)
 
-            if client.config.log_start_trace_span:
+            if (
+                client.config.log_start_trace_span
+                and tracing_runtime_config.is_tracing_active()
+            ):
                 client.trace(**created_trace_data.as_start_parameters)
 
         context_storage.add_span_data(created_span_data)
@@ -485,9 +499,6 @@ class BaseTrackDecorator(abc.ABC):
         generators_trace_to_end: Optional[trace.TraceData] = None,
         flush: bool = False,
     ) -> None:
-        if self.disabled:
-            return
-
         if generators_span_to_end is None:
             span_data_to_end, trace_data_to_end = pop_end_candidates()
         else:
