@@ -6,22 +6,20 @@ from langchain_core import language_models
 from langchain_core.tracers import BaseTracer
 from langchain_core.tracers.schemas import Run
 
-from opik import dict_utils, llm_usage
+import opik.dict_utils as dict_utils
+import opik.llm_usage as llm_usage
 from opik.api_objects import span, trace
 from opik.types import DistributedTraceHeadersDict, ErrorInfoDict
 from opik.validation import parameters_validator
 from . import (
     base_llm_patcher,
-    vertexai_run_helpers,
-    google_generative_ai_helpers,
-    openai_run_helpers,
-    anthropic_run_helpers,
-    anthropic_vertexai_run_helpers,
     opik_encoder_extension,
-    groq_run_helpers,
+    provider_usage_extractors,
 )
+
 from ...api_objects import helpers, opik_client
-from opik import context_storage
+import opik.context_storage as context_storage
+import opik.decorator.tracing_runtime_config as tracing_runtime_config
 
 if TYPE_CHECKING:
     from uuid import UUID
@@ -115,6 +113,14 @@ class OpikTracer(BaseTracer):
             Optional[str]
         ] = contextvars.ContextVar("root_run_external_parent_span_id", default=None)
 
+    def _is_opik_span_created_by_this_tracer(self, span_id: str) -> bool:
+        return any(span.id == span_id for span in self._span_data_map.values())
+
+    def _is_opik_trace_created_by_this_tracer(self, trace_id: str) -> bool:
+        return any(
+            trace.id == trace_id for trace in self._created_traces_data_map.values()
+        )
+
     def _persist_run(self, run: "Run") -> None:
         run_dict: Dict[str, Any] = run.dict()
 
@@ -131,6 +137,16 @@ class OpikTracer(BaseTracer):
 
         span_data = self._span_data_map[run.id]
 
+        if (
+            span_data.parent_span_id is not None
+            and self._is_opik_span_created_by_this_tracer(span_data.parent_span_id)
+        ):
+            # Langchain lost parent-child relationship for Run, so it calls _persist_run
+            # for a subchain when the ACTUAL root run is not yet persisted.
+            # However we know that the parent span was created by this tracer, so we don't
+            # want to finalize the trace
+            return
+
         self._ensure_no_hanging_opik_tracer_spans()
 
         if span_data.trace_id not in self._externally_created_traces_ids:
@@ -251,7 +267,8 @@ class OpikTracer(BaseTracer):
             type=_get_span_type(run_dict),
         )
         self._span_data_map[run_dict["id"]] = span_data
-        self._externally_created_traces_ids.add(span_data.trace_id)
+        if not self._is_opik_trace_created_by_this_tracer(span_data.trace_id):
+            self._externally_created_traces_ids.add(span_data.trace_id)
 
         return span_data
 
@@ -277,7 +294,8 @@ class OpikTracer(BaseTracer):
             type=_get_span_type(run_dict),
         )
         self._span_data_map[run_dict["id"]] = span_data
-        self._externally_created_traces_ids.add(current_trace_data.id)
+        if not self._is_opik_trace_created_by_this_tracer(current_trace_data.id):
+            self._externally_created_traces_ids.add(current_trace_data.id)
         return span_data
 
     def _attach_span_to_distributed_headers(
@@ -312,11 +330,17 @@ class OpikTracer(BaseTracer):
             new_trace_data, new_span_data = self._track_root_run(run_dict)
             if new_trace_data is not None:
                 self._opik_context_storage.set_trace_data(new_trace_data)
-                if self._opik_client.config.log_start_trace_span:
+                if (
+                    self._opik_client.config.log_start_trace_span
+                    and tracing_runtime_config.is_tracing_active()
+                ):
                     self._opik_client.trace(**new_trace_data.as_start_parameters)
 
             self._opik_context_storage.add_span_data(new_span_data)
-            if self._opik_client.config.log_start_trace_span:
+            if (
+                self._opik_client.config.log_start_trace_span
+                and tracing_runtime_config.is_tracing_active()
+            ):
                 self._opik_client.span(**new_span_data.as_start_parameters)
             return
 
@@ -346,27 +370,22 @@ class OpikTracer(BaseTracer):
             ]
 
         self._opik_context_storage.add_span_data(new_span_data)
-        if self._opik_client.config.log_start_trace_span:
+        if (
+            self._opik_client.config.log_start_trace_span
+            and tracing_runtime_config.is_tracing_active()
+        ):
             self._opik_client.span(**new_span_data.as_start_parameters)
 
     def _process_end_span(self, run: "Run") -> None:
         try:
             run_dict: Dict[str, Any] = run.dict()
             span_data = self._span_data_map[run.id]
-            usage_info = llm_usage.LLMUsageInfo()
 
-            if openai_run_helpers.is_openai_run(run):
-                usage_info = openai_run_helpers.get_llm_usage_info(run_dict)
-            elif anthropic_vertexai_run_helpers.is_anthropic_vertexai_run(run):
-                usage_info = anthropic_vertexai_run_helpers.get_llm_usage_info(run_dict)
-            elif vertexai_run_helpers.is_vertexai_run(run):
-                usage_info = vertexai_run_helpers.get_llm_usage_info(run_dict)
-            elif google_generative_ai_helpers.is_google_generative_ai_run(run):
-                usage_info = google_generative_ai_helpers.get_llm_usage_info(run_dict)
-            elif anthropic_run_helpers.is_anthropic_run(run):
-                usage_info = anthropic_run_helpers.get_llm_usage_info(run_dict)
-            elif groq_run_helpers.is_groq_run(run):
-                usage_info = groq_run_helpers.get_llm_usage_info(run_dict)
+            usage_info = provider_usage_extractors.try_extract_provider_usage_data(
+                run_dict
+            )
+            if usage_info is None:
+                usage_info = llm_usage.LLMUsageInfo()
 
             # workaround for `.astream()` method usage
             if span_data.input == {"input": ""}:
@@ -374,14 +393,17 @@ class OpikTracer(BaseTracer):
 
             span_data.init_end_time().update(
                 output=run_dict["outputs"],
-                usage=usage_info.usage.provider_usage.model_dump()
-                if isinstance(usage_info.usage, llm_usage.OpikUsage)
-                else usage_info.usage,
+                usage=(
+                    usage_info.usage.provider_usage.model_dump()
+                    if isinstance(usage_info.usage, llm_usage.OpikUsage)
+                    else usage_info.usage
+                ),
                 provider=usage_info.provider,
                 model=usage_info.model,
             )
 
-            self._opik_client.span(**span_data.as_parameters)
+            if tracing_runtime_config.is_tracing_active():
+                self._opik_client.span(**span_data.as_parameters)
         except Exception as e:
             LOGGER.error(f"Failed during _process_end_span: {e}", exc_info=True)
         finally:
@@ -403,7 +425,8 @@ class OpikTracer(BaseTracer):
                 output=None,
                 error_info=error_info,
             )
-            self._opik_client.span(**span_data.as_parameters)
+            if tracing_runtime_config.is_tracing_active():
+                self._opik_client.span(**span_data.as_parameters)
         except Exception as e:
             LOGGER.debug(f"Failed during _process_end_span_with_error: {e}")
         finally:
@@ -436,8 +459,7 @@ class OpikTracer(BaseTracer):
         return self._created_traces
 
     def _skip_tracking(self) -> bool:
-        config = self._opik_client.config
-        if config.track_disable:
+        if not tracing_runtime_config.is_tracing_active():
             return True
 
         return False
@@ -497,6 +519,7 @@ class OpikTracer(BaseTracer):
             tags=tags,
             name=name,  # type: ignore[arg-type]
         )
+
         self._start_trace(chat_model_run)
         self._on_chat_model_start(chat_model_run)
         return chat_model_run
