@@ -9,7 +9,7 @@ from . import (
     bedrock_usage,
     openai_responses_usage,
 )
-from opik import dict_utils
+import opik.dict_utils as dict_utils
 
 ProviderUsage = Union[
     openai_chat_completions_usage.OpenAICompletionsUsage,
