@@ -16,24 +16,27 @@ AttachmentEntityType = Literal["trace", "span"]
 
 
 class LLMProvider(str, enum.Enum):
-    GOOGLE_VERTEXAI: str = "google_vertexai"
+    GOOGLE_VERTEXAI = "google_vertexai"
     """Used for gemini models hosted in VertexAI. https://cloud.google.com/vertex-ai"""
 
-    GOOGLE_AI: str = "google_ai"
+    GOOGLE_AI = "google_ai"
     """Used for gemini models hosted in GoogleAI. https://ai.google.dev/aistudio"""
 
-    OPENAI: str = "openai"
+    OPENAI = "openai"
     """Used for models hosted by OpenAI. https://platform.openai.com"""
 
-    ANTHROPIC: str = "anthropic"
+    ANTHROPIC = "anthropic"
     """Used for models hosted by Anthropic. https://www.anthropic.com"""
 
-    ANTHROPIC_VERTEXAI: str = "anthropic_vertexai"
+    ANTHROPIC_VERTEXAI = "anthropic_vertexai"
     """Used for Anthropic models hosted by VertexAI. https://cloud.google.com/vertex-ai"""
 
     GROQ = "groq"
     """Used for models hosted by Groq. https://groq.com"""
 
+    BEDROCK = "bedrock"
+    """Used for models hosted by AWS Bedrock. https://aws.amazon.com/bedrock"""
+
     @classmethod
     def has_value(cls, value: str) -> bool:
         return value in [enum_item.value for enum_item in cls]
